## What is bisheng-langchain?

bisheng-langchain is an open-source langchain extending library built to power building LLM application.
bisheng-langchain provides more components to support Chinese LLMs and and Chinese based token environments for prompt engineering and ICL template.


The project is a sub-module of [bisheng](https://github.com/dataelement/bisheng).


## Key features

- Retrival Enhancement components, like ESIndex, DBIndex, GraphIndex 
- Supporting Open LLMs and embeddings models 
- High performance QAs Chains
- High Semanticly Chinese token processing


## Quick start

### Start with Bisheng Platform.

We provide a open cloud service for easily use. See [free trial](https://bisheng.dataelem.com/).


### Install bisheng-langchain

- Install from pip: `pip install bisheng-langchain`
- [Quick Start Guide](https://m7a7tqsztt.feishu.cn/wiki/CTXNwpqGKiMs5FkKlPJcylfonuD)


## Documentation

For guidance on installation, development, deployment, and administration, 
check out [bisheng-langchain Dev Docs](https://dataelem.feishu.cn/wiki/Xaq8wKQjkiYEHNkXuYLc7JkxnPf). 


## Acknowledgments

bisheng-langchain adopts dependencies from the following:

- Thanks to [langchain](https://github.com/langchain-ai/langchain) for the main framework.
